@@ -1,6 +1,6 @@
 package Path::Class;
 
-$VERSION = '0.04';
+$VERSION = '0.05';
 @ISA = qw(Exporter);
 @EXPORT    = qw(file dir);
 @EXPORT_OK = qw(file dir foreign_file foreign_dir);
@@ -141,7 +141,7 @@ A synonym for C<< Path::Class::Dir->new_foreign >>.
 
 =head1 AUTHOR
 
-Ken Williams, ken@mathforum.org
+Ken Williams, KWILLIAMS@cpan.org
 
 =head1 SEE ALSO
 
