@@ -5,6 +5,9 @@ use Path::Class::File;
 use Path::Class::Entity;
 use base qw(Path::Class::Entity);
 
+use IO::Dir ();
+use File::Path ();
+
 sub new {
   my $self = shift->SUPER::new();
   my $s = $self->_spec;
@@ -81,6 +84,30 @@ sub parent {
   }
 }
 
+sub open  { IO::Dir->new(@_) }
+sub mkpath { File::Path::mkpath(shift()->stringify, @_) }
+sub rmtree { File::Path::rmtree(shift()->stringify, @_) }
+
+sub next {
+  my $self = shift;
+  unless ($self->{dh}) {
+    $self->{dh} = $self->open or die "Can't open directory $self: $!";
+  }
+  
+  my $next = $self->{dh}->read;
+  unless (defined $next) {
+    delete $self->{dh};
+    return undef;
+  }
+  
+  # Have to figure out whether it's a file or directory
+  my $file = Path::Class::File->new($self, $next);
+  if (-d $file) {
+    $file = $self->new($self, $next);
+  }
+  return $file;
+}
+
 1;
 __END__
 
@@ -275,6 +302,22 @@ there is a subclass of C<File::Spec>.
 The arguments in C<@args> are the same as they would be specified in
 C<new()>.
 
+=item $fh = $dir->open()
+
+Passes C<$dir> to C<< IO::Dir->open >> and returns the result as an
+C<IO::Dir> object.  If the opening fails, C<undef> is returned and
+C<$!> is set.
+
+=item $dir->mkpath($verbose, $mode)
+
+Passes all arguments, including C<$dir>, to C<< Path::Class::mkpath()
+>> and returns the result (a list of all directories created).
+
+=item $dir->rmtree($verbose, $cautious)
+
+Passes all arguments, including C<$dir>, to C<< Path::Class::rmtree()
+>> and returns the result (the number of files successfully deleted).
+
 =back
 
 =head1 AUTHOR
